import 'package:flutter/material.dart';
import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:momomotus/common/cubit/nav/nav_cubit_pages.dart';

import 'package:momomotus/cubit/activity/activity_cubit.dart';
import 'package:momomotus/ui/parameters/parameter_painter_difficulty_level.dart';

class ApplicationConfig {
  static const String parameterCodeSkin = 'global.skin';
  static const String parameterCodeLang = 'activity.lang';
  static const String parameterCodeWordLength = 'activity.wordLength';
  static const String parameterCodeDifficultyLevel = 'activity.difficultyLevel';

  static const String skinValueDefault = 'default';

  static const String langValueFr = 'fr';

  static const String wordLengthValue4 = '4';
  static const String wordLengthValue5 = '5';
  static const String wordLengthValue6 = '6';
  static const String wordLengthValue7 = '7';
  static const String wordLengthValue8 = '8';

  static const String difficultyLevelValueEasy = 'easy';
  static const String difficultyLevelValueNormal = 'normal';

  static const int maxGuessesCount = 7;

  static final ApplicationConfigDefinition config = ApplicationConfigDefinition(
    appTitle: 'Momomotus',
    activitySettings: [
      // skin
      ApplicationSettingsParameter(
        code: parameterCodeSkin,
        values: [
          ApplicationSettingsParameterItemValue(
            value: skinValueDefault,
            isDefault: true,
          ),
        ],
      ),

      // lang
      ApplicationSettingsParameter(
        code: parameterCodeLang,
        values: [
          ApplicationSettingsParameterItemValue(
            value: langValueFr,
            isDefault: true,
          ),
        ],
      ),

      // word length
      ApplicationSettingsParameter(
        code: parameterCodeWordLength,
        values: [
          ApplicationSettingsParameterItemValue(
            value: wordLengthValue4,
            color: Colors.green,
            text: '4️⃣',
          ),
          ApplicationSettingsParameterItemValue(
            value: wordLengthValue5,
            color: Colors.yellow,
            text: '5️⃣',
            isDefault: true,
          ),
          ApplicationSettingsParameterItemValue(
            value: wordLengthValue6,
            color: Colors.orange,
            text: '6️⃣',
          ),
          ApplicationSettingsParameterItemValue(
            value: wordLengthValue7,
            color: Colors.red,
            text: '7️⃣',
          ),
          ApplicationSettingsParameterItemValue(
            value: wordLengthValue8,
            color: Colors.purple,
            text: '8️⃣',
          ),
        ],
      ),

      // difficulty level
      ApplicationSettingsParameter(
        code: parameterCodeDifficultyLevel,
        values: [
          ApplicationSettingsParameterItemValue(
            value: difficultyLevelValueEasy,
            color: Colors.green,
            isDefault: true,
          ),
          ApplicationSettingsParameterItemValue(
            value: difficultyLevelValueNormal,
            color: Colors.orange,
          ),
        ],
        customPainter: (context, value) => ParameterPainterDifficultyLevel(
          context: context,
          value: value,
        ),
      ),
    ],
    startNewActivity: (BuildContext context) {
      BlocProvider.of<ActivityCubit>(context).startNewActivity(context);
      BlocProvider.of<NavCubitPage>(context).goToPageGame();
    },
    deleteCurrentActivity: (BuildContext context) {
      BlocProvider.of<ActivityCubit>(context).deleteSavedActivity();
    },
    resumeActivity: (BuildContext context) {
      BlocProvider.of<ActivityCubit>(context).resumeSavedActivity();
      BlocProvider.of<NavCubitPage>(context).goToPageGame();
    },
  );
}
